==> latrace_0.5.10.20110523.orig.tar.gz: latrace-0.5.10.20110523/test/lib-test-args.c <==

char test_char_1(char a)
{
	return a*a;
}

char test_char_2(char a, char b)
{
	return a - b;
}

char test_char_3(char a, char b, char c)
{
	return a * b - c;
}

char test_char_4(char a, char b, char c, char d)
{
	return a + b - c * d;
}

char test_char_5(char a, char b, char c, char d, char e)
{
	return a + b * c / d * e;
}

char test_char_6(char a, char b, char c, char d, char e, char f)
{
	return a / b * c / d * e - f;
}

char test_char_7(char a, char b, char c, char d, char e, char f, char g)
{
	return a / b + c - d * e + f * g;
}

char test_char_8(char a, char b, char c, char d, char e, char f, char g, char h)
{
	return a + b + c - d + e - f + g / h;
}

char test_char_9(char a, char b, char c, char d, char e, char f, char g, char h, char i)
{
	return a - b + c - d * e - f / g - h - i;
}

short test_short_1(short a)
{
	return -a;
}

short test_short_2(short a, short b)
{
	return a + b;
}

short test_short_3(short a, short b, short c)
{
	return a + b - c;
}

short test_short_4(short a, short b, short c, short d)
{
	return a + b * c + d;
}

short test_short_5(short a, short b, short c, short d, short e)
{
	return a + b - c + d * e;
}

short test_short_6(short a, short b, short c, short d, short e, short f)
{
	return a * b * c + d * e - f;
}

short test_short_7(short a, short b, short c, short d, short e, short f, short g)
{
	return a / b + c + d * e - f * g;
}

short test_short_8(short a, short b, short c, short d, short e, short f, short g, short h)
{
	return a + b + c + d + e + f + g + h;
}

short test_short_9(short a, short b, short c, short d, short e, short f, short g, short h, short i)
{
	return a - b - c - d - e - f - g - h - i;
}

int test_int_1(int a)
{
	return -a;
}

int test_int_2(int a, int b)
{
	return a + b;
}

int test_int_3(int a, int b, int c)
{
	return a + b - c;
}

int test_int_4(int a, int b, int c, int d)
{
	return a + b * c + d;
}

int test_int_5(int a, int b, int c, int d, int e)
{
	return a + b - c + d * e;
}

int test_int_6(int a, int b, int c, int d, int e, int f)
{
	return a * b * c + d * e - f;
}

int test_int_7(int a, int b, int c, int d, int e, int f, int g)
{
	return a / b + c + d * e - f * g;
}

int test_int_8(int a, int b, int c, int d, int e, int f, int g, int h)
{
	return a + b + c + d + e + f + g + h;
}

int test_int_9(int a, int b, int c, int d, int e, int f, int g, int h, int i)
{
	return a - b - c - d - e - f - g - h - i;
}

long test_long_1(long a)
{
	return -a;
}

long test_long_2(long a, long b)
{
	return a + b;
}

long test_long_3(long a, long b, long c)
{
	return a + b - c;
}

long test_long_4(long a, long b, long c, long d)
{
	return a + b * c + d;
}

long test_long_5(long a, long b, long c, long d, long e)
{
	return a + b - c + d * e;
}

long test_long_6(long a, long b, long c, long d, long e, long f)
{
	return a * b * c + d * e - f;
}

long test_long_7(long a, long b, long c, long d, long e, long f, long g)
{
	return a / b + c + d * e - f * g;
}

long test_long_8(long a, long b, long c, long d, long e, long f, long g, long h)
{
	return a + b + c + d + e + f + g + h;
}

long test_long_9(long a, long b, long c, long d, long e, long f, long g, long h, long i)
{
	return a - b - c - d - e - f - g - h - i;
}

==> latrace_0.5.11.orig.tar.gz: latrace-0.5.11.orig/test/lib-test-args.c <==

char test_char_1(char a)
{
	return 'd';
}

char test_char_2(char a, char b)
{
	return 0xf6;
}

char test_char_3(char a, char b, char c)
{
	return 0xf7;
}

char test_char_4(char a, char b, char c, char d)
{
	return 0xc9;
}

char test_char_5(char a, char b, char c, char d, char e)
{
	return 0x2;
}

char test_char_6(char a, char b, char c, char d, char e, char f)
{
	return 'c';
}

char test_char_7(char a, char b, char c, char d, char e, char f, char g)
{
	return 0x19;
}

char test_char_8(char a, char b, char c, char d, char e, char f, char g, char h)
{
	return '9';
}

char test_char_9(char a, char b, char c, char d, char e, char f, char g, char h, char i)
{
	return 0xd0;
}

short test_short_1(short a)
{
	return -100;
}

short test_short_2(short a, short b)
{
	return 30;
}

short test_short_3(short a, short b, short c)
{
	return -8;
}

short test_short_4(short a, short b, short c, short d)
{
	return 2097;
}

short test_short_5(short a, short b, short c, short d, short e)
{
	return 1583;
}

short test_short_6(short a, short b, short c, short d, short e, short f)
{
	return -25344;
}

short test_short_7(short a, short b, short c, short d, short e, short f, short g)
{
	return -19;
}

short test_short_8(short a, short b, short c, short d, short e, short f, short g, short h)
{
	return 3134;
}

short test_short_9(short a, short b, short c, short d, short e, short f, short g, short h, short i)
{
	return -2482;
}

int test_int_1(int a)
{
	return -100;
}

int test_int_2(int a, int b)
{
	return 30;
}

int test_int_3(int a, int b, int c)
{
	return -8;
}

int test_int_4(int a, int b, int c, int d)
{
	return 200997;
}

int test_int_5(int a, int b, int c, int d, int e)
{
	return -2144725863;
}

int test_int_6(int a, int b, int c, int d, int e, int f)
{
	return -1223446720;
}

int test_int_7(int a, int b, int c, int d, int e, int f, int g)
{
	return -19;
}

int test_int_8(int a, int b, int c, int d, int e, int f, int g, int h)
{
	return 214322534;
}

int test_int_9(int a, int b, int c, int d, int e, int f, int g, int h, int i)
{
	return -2482;
}

long test_long_1(long a)
{
	return -a;
}

long test_long_2(long a, long b)
{
	return a * b;
}

long test_long_3(long a, long b, long c)
{
	return a * b * c;
}

long test_long_4(long a, long b, long c, long d)
{
	return a * b * c * d;
}

long test_long_5(long a, long b, long c, long d, long e)
{
	return a * b * c * d * e;
}

long test_long_6(long a, long b, long c, long d, long e, long f)
{
	return a * b * c * d * e * f;
}

long test_long_7(long a, long b, long c, long d, long e, long f, long g)
{
	return a * b * c * d * e * f * g;
}

long test_long_8(long a, long b, long c, long d, long e, long f, long g, long h)
{
	return 0;
}

long test_long_9(long a, long b, long c, long d, long e, long f, long g, long h, long i)
{
	return a * b * c * d * e * f * g * h * i;
}
